Class: Aws::IoTFleetWise::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTFleetWise::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotfleetwise/client.rb,
sig/client.rbs
Overview
An API client for IoTFleetWise. To construct a client, you need to configure a :region and :credentials.
client = Aws::IoTFleetWise::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateVehicleFleetResponseSuccess, _BatchCreateVehicleResponseSuccess, _BatchUpdateVehicleResponseSuccess, _CreateCampaignResponseSuccess, _CreateDecoderManifestResponseSuccess, _CreateFleetResponseSuccess, _CreateModelManifestResponseSuccess, _CreateSignalCatalogResponseSuccess, _CreateStateTemplateResponseSuccess, _CreateVehicleResponseSuccess, _DeleteCampaignResponseSuccess, _DeleteDecoderManifestResponseSuccess, _DeleteFleetResponseSuccess, _DeleteModelManifestResponseSuccess, _DeleteSignalCatalogResponseSuccess, _DeleteStateTemplateResponseSuccess, _DeleteVehicleResponseSuccess, _DisassociateVehicleFleetResponseSuccess, _GetCampaignResponseSuccess, _GetDecoderManifestResponseSuccess, _GetEncryptionConfigurationResponseSuccess, _GetFleetResponseSuccess, _GetLoggingOptionsResponseSuccess, _GetModelManifestResponseSuccess, _GetRegisterAccountStatusResponseSuccess, _GetSignalCatalogResponseSuccess, _GetStateTemplateResponseSuccess, _GetVehicleResponseSuccess, _GetVehicleStatusResponseSuccess, _ImportDecoderManifestResponseSuccess, _ImportSignalCatalogResponseSuccess, _ListCampaignsResponseSuccess, _ListDecoderManifestNetworkInterfacesResponseSuccess, _ListDecoderManifestSignalsResponseSuccess, _ListDecoderManifestsResponseSuccess, _ListFleetsForVehicleResponseSuccess, _ListFleetsResponseSuccess, _ListModelManifestNodesResponseSuccess, _ListModelManifestsResponseSuccess, _ListSignalCatalogNodesResponseSuccess, _ListSignalCatalogsResponseSuccess, _ListStateTemplatesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVehiclesInFleetResponseSuccess, _ListVehiclesResponseSuccess, _PutEncryptionConfigurationResponseSuccess, _PutLoggingOptionsResponseSuccess, _RegisterAccountResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateCampaignResponseSuccess, _UpdateDecoderManifestResponseSuccess, _UpdateFleetResponseSuccess, _UpdateModelManifestResponseSuccess, _UpdateSignalCatalogResponseSuccess, _UpdateStateTemplateResponseSuccess, _UpdateVehicleResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_vehicle_fleet(params = {}) ⇒ Struct
Adds, or associates, a vehicle with a fleet.
-
#batch_create_vehicle(params = {}) ⇒ Types::BatchCreateVehicleResponse
Creates a group, or batch, of vehicles.
-
#batch_update_vehicle(params = {}) ⇒ Types::BatchUpdateVehicleResponse
Updates a group, or batch, of vehicles.
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates an orchestration of data collection rules.
-
#create_decoder_manifest(params = {}) ⇒ Types::CreateDecoderManifestResponse
Creates the decoder manifest associated with a model manifest.
-
#create_fleet(params = {}) ⇒ Types::CreateFleetResponse
Creates a fleet that represents a group of vehicles.
-
#create_model_manifest(params = {}) ⇒ Types::CreateModelManifestResponse
Creates a vehicle model (model manifest) that specifies signals (attributes, branches, sensors, and actuators).
-
#create_signal_catalog(params = {}) ⇒ Types::CreateSignalCatalogResponse
Creates a collection of standardized signals that can be reused to create vehicle models.
-
#create_state_template(params = {}) ⇒ Types::CreateStateTemplateResponse
Creates a state template.
-
#create_vehicle(params = {}) ⇒ Types::CreateVehicleResponse
Creates a vehicle, which is an instance of a vehicle model (model manifest).
-
#delete_campaign(params = {}) ⇒ Types::DeleteCampaignResponse
Deletes a data collection campaign.
-
#delete_decoder_manifest(params = {}) ⇒ Types::DeleteDecoderManifestResponse
Deletes a decoder manifest.
-
#delete_fleet(params = {}) ⇒ Types::DeleteFleetResponse
Deletes a fleet.
-
#delete_model_manifest(params = {}) ⇒ Types::DeleteModelManifestResponse
Deletes a vehicle model (model manifest).
-
#delete_signal_catalog(params = {}) ⇒ Types::DeleteSignalCatalogResponse
Deletes a signal catalog.
-
#delete_state_template(params = {}) ⇒ Types::DeleteStateTemplateResponse
Deletes a state template.
-
#delete_vehicle(params = {}) ⇒ Types::DeleteVehicleResponse
Deletes a vehicle and removes it from any campaigns.
-
#disassociate_vehicle_fleet(params = {}) ⇒ Struct
Removes, or disassociates, a vehicle from a fleet.
-
#get_campaign(params = {}) ⇒ Types::GetCampaignResponse
Retrieves information about a campaign.
-
#get_decoder_manifest(params = {}) ⇒ Types::GetDecoderManifestResponse
Retrieves information about a created decoder manifest.
-
#get_encryption_configuration(params = {}) ⇒ Types::GetEncryptionConfigurationResponse
Retrieves the encryption configuration for resources and data in Amazon Web Services IoT FleetWise.
-
#get_fleet(params = {}) ⇒ Types::GetFleetResponse
Retrieves information about a fleet.
-
#get_logging_options(params = {}) ⇒ Types::GetLoggingOptionsResponse
Retrieves the logging options.
-
#get_model_manifest(params = {}) ⇒ Types::GetModelManifestResponse
Retrieves information about a vehicle model (model manifest).
-
#get_register_account_status(params = {}) ⇒ Types::GetRegisterAccountStatusResponse
Retrieves information about the status of registering your Amazon Web Services account, IAM, and Amazon Timestream resources so that Amazon Web Services IoT FleetWise can transfer your vehicle data to the Amazon Web Services Cloud.
-
#get_signal_catalog(params = {}) ⇒ Types::GetSignalCatalogResponse
Retrieves information about a signal catalog.
-
#get_state_template(params = {}) ⇒ Types::GetStateTemplateResponse
Retrieves information about a state template.
-
#get_vehicle(params = {}) ⇒ Types::GetVehicleResponse
Retrieves information about a vehicle.
-
#get_vehicle_status(params = {}) ⇒ Types::GetVehicleStatusResponse
Retrieves information about the status of campaigns, decoder manifests, or state templates associated with a vehicle.
-
#import_decoder_manifest(params = {}) ⇒ Types::ImportDecoderManifestResponse
Creates a decoder manifest using your existing CAN DBC file from your local device.
-
#import_signal_catalog(params = {}) ⇒ Types::ImportSignalCatalogResponse
Creates a signal catalog using your existing VSS formatted content from your local device.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Lists information about created campaigns.
-
#list_decoder_manifest_network_interfaces(params = {}) ⇒ Types::ListDecoderManifestNetworkInterfacesResponse
Lists the network interfaces specified in a decoder manifest.
-
#list_decoder_manifest_signals(params = {}) ⇒ Types::ListDecoderManifestSignalsResponse
A list of information about signal decoders specified in a decoder manifest.
-
#list_decoder_manifests(params = {}) ⇒ Types::ListDecoderManifestsResponse
Lists decoder manifests.
-
#list_fleets(params = {}) ⇒ Types::ListFleetsResponse
Retrieves information for each created fleet in an Amazon Web Services account.
-
#list_fleets_for_vehicle(params = {}) ⇒ Types::ListFleetsForVehicleResponse
Retrieves a list of IDs for all fleets that the vehicle is associated with.
-
#list_model_manifest_nodes(params = {}) ⇒ Types::ListModelManifestNodesResponse
Lists information about nodes specified in a vehicle model (model manifest).
-
#list_model_manifests(params = {}) ⇒ Types::ListModelManifestsResponse
Retrieves a list of vehicle models (model manifests).
-
#list_signal_catalog_nodes(params = {}) ⇒ Types::ListSignalCatalogNodesResponse
Lists of information about the signals (nodes) specified in a signal catalog.
-
#list_signal_catalogs(params = {}) ⇒ Types::ListSignalCatalogsResponse
Lists all the created signal catalogs in an Amazon Web Services account.
-
#list_state_templates(params = {}) ⇒ Types::ListStateTemplatesResponse
Lists information about created state templates.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
-
#list_vehicles(params = {}) ⇒ Types::ListVehiclesResponse
Retrieves a list of summaries of created vehicles.
-
#list_vehicles_in_fleet(params = {}) ⇒ Types::ListVehiclesInFleetResponse
Retrieves a list of summaries of all vehicles associated with a fleet.
-
#put_encryption_configuration(params = {}) ⇒ Types::PutEncryptionConfigurationResponse
Creates or updates the encryption configuration.
-
#put_logging_options(params = {}) ⇒ Struct
Creates or updates the logging option.
-
#register_account(params = {}) ⇒ Types::RegisterAccountResponse
This API operation contains deprecated parameters.
-
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the given tags (metadata) from the resource.
-
#update_campaign(params = {}) ⇒ Types::UpdateCampaignResponse
Updates a campaign.
-
#update_decoder_manifest(params = {}) ⇒ Types::UpdateDecoderManifestResponse
Updates a decoder manifest.
-
#update_fleet(params = {}) ⇒ Types::UpdateFleetResponse
Updates the description of an existing fleet.
-
#update_model_manifest(params = {}) ⇒ Types::UpdateModelManifestResponse
Updates a vehicle model (model manifest).
-
#update_signal_catalog(params = {}) ⇒ Types::UpdateSignalCatalogResponse
Updates a signal catalog.
-
#update_state_template(params = {}) ⇒ Types::UpdateStateTemplateResponse
Updates a state template.
-
#update_vehicle(params = {}) ⇒ Types::UpdateVehicleResponse
Updates a vehicle.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4268 4269 4270 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4268 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4271 4272 4273 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4271 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_vehicle_fleet(params = {}) ⇒ Struct
Adds, or associates, a vehicle with a fleet.
86 |
# File 'sig/client.rbs', line 86
def associate_vehicle_fleet: (
|
#batch_create_vehicle(params = {}) ⇒ Types::BatchCreateVehicleResponse
Creates a group, or batch, of vehicles.
For more information, see Create multiple vehicles (AWS CLI) in the Amazon Web Services IoT FleetWise Developer Guide.
98 |
# File 'sig/client.rbs', line 98
def batch_create_vehicle: (
|
#batch_update_vehicle(params = {}) ⇒ Types::BatchUpdateVehicleResponse
Updates a group, or batch, of vehicles.
For more information, see Update multiple vehicles (AWS CLI) in the Amazon Web Services IoT FleetWise Developer Guide.
126 |
# File 'sig/client.rbs', line 126
def batch_update_vehicle: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4241 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTFleetWise') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotfleetwise' context[:gem_version] = '1.68.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates an orchestration of data collection rules. The Amazon Web Services IoT FleetWise Edge Agent software running in vehicles uses campaigns to decide how to collect and transfer data to the cloud. You create campaigns in the cloud. After you or your team approve campaigns, Amazon Web Services IoT FleetWise automatically deploys them to vehicles.
For more information, see Collect and transfer data with campaigns in the Amazon Web Services IoT FleetWise Developer Guide.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.
152 |
# File 'sig/client.rbs', line 152
def create_campaign: (
|
#create_decoder_manifest(params = {}) ⇒ Types::CreateDecoderManifestResponse
Creates the decoder manifest associated with a model manifest. To create a decoder manifest, the following must be true:
-
Every signal decoder has a unique name.
-
Each signal decoder is associated with a network interface.
-
Each network interface has a unique ID.
-
The signal decoders are specified in the model manifest.
253 |
# File 'sig/client.rbs', line 253
def create_decoder_manifest: (
|
#create_fleet(params = {}) ⇒ Types::CreateFleetResponse
Creates a fleet that represents a group of vehicles.
For more information, see Fleets in the Amazon Web Services IoT FleetWise Developer Guide.
279 |
# File 'sig/client.rbs', line 279
def create_fleet: (
|
#create_model_manifest(params = {}) ⇒ Types::CreateModelManifestResponse
Creates a vehicle model (model manifest) that specifies signals (attributes, branches, sensors, and actuators).
For more information, see Vehicle models in the Amazon Web Services IoT FleetWise Developer Guide.
298 |
# File 'sig/client.rbs', line 298
def create_model_manifest: (
|
#create_signal_catalog(params = {}) ⇒ Types::CreateSignalCatalogResponse
Creates a collection of standardized signals that can be reused to create vehicle models.
318 |
# File 'sig/client.rbs', line 318
def create_signal_catalog: (
|
#create_state_template(params = {}) ⇒ Types::CreateStateTemplateResponse
Creates a state template. State templates contain state properties, which are signals that belong to a signal catalog that is synchronized between the Amazon Web Services IoT FleetWise Edge and the Amazon Web Services Cloud.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.
340 |
# File 'sig/client.rbs', line 340
def create_state_template: (
|
#create_vehicle(params = {}) ⇒ Types::CreateVehicleResponse
Creates a vehicle, which is an instance of a vehicle model (model manifest). Vehicles created from the same vehicle model consist of the same signals inherited from the vehicle model.
For more information, see Create a vehicle (AWS CLI) in the Amazon Web Services IoT FleetWise Developer Guide.
363 |
# File 'sig/client.rbs', line 363
def create_vehicle: (
|
#delete_campaign(params = {}) ⇒ Types::DeleteCampaignResponse
Deletes a data collection campaign. Deleting a campaign suspends all data collection and removes it from any vehicles.
387 |
# File 'sig/client.rbs', line 387
def delete_campaign: (
|
#delete_decoder_manifest(params = {}) ⇒ Types::DeleteDecoderManifestResponse
Deletes a decoder manifest. You can't delete a decoder manifest if it has vehicles associated with it.
398 |
# File 'sig/client.rbs', line 398
def delete_decoder_manifest: (
|
#delete_fleet(params = {}) ⇒ Types::DeleteFleetResponse
Deletes a fleet. Before you delete a fleet, all vehicles must be dissociated from the fleet. For more information, see Delete a fleet (AWS CLI) in the Amazon Web Services IoT FleetWise Developer Guide.
409 |
# File 'sig/client.rbs', line 409
def delete_fleet: (
|
#delete_model_manifest(params = {}) ⇒ Types::DeleteModelManifestResponse
Deletes a vehicle model (model manifest).
420 |
# File 'sig/client.rbs', line 420
def delete_model_manifest: (
|
#delete_signal_catalog(params = {}) ⇒ Types::DeleteSignalCatalogResponse
Deletes a signal catalog.
431 |
# File 'sig/client.rbs', line 431
def delete_signal_catalog: (
|
#delete_state_template(params = {}) ⇒ Types::DeleteStateTemplateResponse
Deletes a state template.
443 |
# File 'sig/client.rbs', line 443
def delete_state_template: (
|
#delete_vehicle(params = {}) ⇒ Types::DeleteVehicleResponse
Deletes a vehicle and removes it from any campaigns.
454 |
# File 'sig/client.rbs', line 454
def delete_vehicle: (
|
#disassociate_vehicle_fleet(params = {}) ⇒ Struct
Removes, or disassociates, a vehicle from a fleet. Disassociating a vehicle from a fleet doesn't delete the vehicle.
463 |
# File 'sig/client.rbs', line 463
def disassociate_vehicle_fleet: (
|
#get_campaign(params = {}) ⇒ Types::GetCampaignResponse
Retrieves information about a campaign.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.
494 |
# File 'sig/client.rbs', line 494
def get_campaign: (
|
#get_decoder_manifest(params = {}) ⇒ Types::GetDecoderManifestResponse
Retrieves information about a created decoder manifest.
511 |
# File 'sig/client.rbs', line 511
def get_decoder_manifest: (
|
#get_encryption_configuration(params = {}) ⇒ Types::GetEncryptionConfigurationResponse
Retrieves the encryption configuration for resources and data in Amazon Web Services IoT FleetWise.
526 |
# File 'sig/client.rbs', line 526
def get_encryption_configuration: (
|
#get_fleet(params = {}) ⇒ Types::GetFleetResponse
Retrieves information about a fleet.
540 |
# File 'sig/client.rbs', line 540
def get_fleet: (
|
#get_logging_options(params = {}) ⇒ Types::GetLoggingOptionsResponse
Retrieves the logging options.
550 |
# File 'sig/client.rbs', line 550
def get_logging_options: (
|
#get_model_manifest(params = {}) ⇒ Types::GetModelManifestResponse
Retrieves information about a vehicle model (model manifest).
565 |
# File 'sig/client.rbs', line 565
def get_model_manifest: (
|
#get_register_account_status(params = {}) ⇒ Types::GetRegisterAccountStatusResponse
Retrieves information about the status of registering your Amazon Web Services account, IAM, and Amazon Timestream resources so that Amazon Web Services IoT FleetWise can transfer your vehicle data to the Amazon Web Services Cloud.
For more information, including step-by-step procedures, see Setting up Amazon Web Services IoT FleetWise.
580 |
# File 'sig/client.rbs', line 580
def get_register_account_status: (
|
#get_signal_catalog(params = {}) ⇒ Types::GetSignalCatalogResponse
Retrieves information about a signal catalog.
594 |
# File 'sig/client.rbs', line 594
def get_signal_catalog: (
|
#get_state_template(params = {}) ⇒ Types::GetStateTemplateResponse
Retrieves information about a state template.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.
613 |
# File 'sig/client.rbs', line 613
def get_state_template: (
|
#get_vehicle(params = {}) ⇒ Types::GetVehicleResponse
Retrieves information about a vehicle.
630 |
# File 'sig/client.rbs', line 630
def get_vehicle: (
|
#get_vehicle_status(params = {}) ⇒ Types::GetVehicleStatusResponse
Retrieves information about the status of campaigns, decoder manifests, or state templates associated with a vehicle.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
641 |
# File 'sig/client.rbs', line 641
def get_vehicle_status: (
|
#import_decoder_manifest(params = {}) ⇒ Types::ImportDecoderManifestResponse
Creates a decoder manifest using your existing CAN DBC file from your local device.
The CAN signal name must be unique and not repeated across CAN message definitions in a .dbc file.
654 |
# File 'sig/client.rbs', line 654
def import_decoder_manifest: (
|
#import_signal_catalog(params = {}) ⇒ Types::ImportSignalCatalogResponse
Creates a signal catalog using your existing VSS formatted content from your local device.
674 |
# File 'sig/client.rbs', line 674
def import_signal_catalog: (
|
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Lists information about created campaigns.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
695 |
# File 'sig/client.rbs', line 695
def list_campaigns: (
|
#list_decoder_manifest_network_interfaces(params = {}) ⇒ Types::ListDecoderManifestNetworkInterfacesResponse
Lists the network interfaces specified in a decoder manifest.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
709 |
# File 'sig/client.rbs', line 709
def list_decoder_manifest_network_interfaces: (
|
#list_decoder_manifest_signals(params = {}) ⇒ Types::ListDecoderManifestSignalsResponse
A list of information about signal decoders specified in a decoder manifest.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
722 |
# File 'sig/client.rbs', line 722
def list_decoder_manifest_signals: (
|
#list_decoder_manifests(params = {}) ⇒ Types::ListDecoderManifestsResponse
Lists decoder manifests.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
735 |
# File 'sig/client.rbs', line 735
def list_decoder_manifests: (
|
#list_fleets(params = {}) ⇒ Types::ListFleetsResponse
Retrieves information for each created fleet in an Amazon Web Services account.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
749 |
# File 'sig/client.rbs', line 749
def list_fleets: (
|
#list_fleets_for_vehicle(params = {}) ⇒ Types::ListFleetsForVehicleResponse
Retrieves a list of IDs for all fleets that the vehicle is associated with.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
762 |
# File 'sig/client.rbs', line 762
def list_fleets_for_vehicle: (
|
#list_model_manifest_nodes(params = {}) ⇒ Types::ListModelManifestNodesResponse
Lists information about nodes specified in a vehicle model (model manifest).
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
775 |
# File 'sig/client.rbs', line 775
def list_model_manifest_nodes: (
|
#list_model_manifests(params = {}) ⇒ Types::ListModelManifestsResponse
Retrieves a list of vehicle models (model manifests).
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
788 |
# File 'sig/client.rbs', line 788
def list_model_manifests: (
|
#list_signal_catalog_nodes(params = {}) ⇒ Types::ListSignalCatalogNodesResponse
Lists of information about the signals (nodes) specified in a signal catalog.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
802 |
# File 'sig/client.rbs', line 802
def list_signal_catalog_nodes: (
|
#list_signal_catalogs(params = {}) ⇒ Types::ListSignalCatalogsResponse
Lists all the created signal catalogs in an Amazon Web Services account.
You can use to list information about each signal (node) specified in a signal catalog.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
816 |
# File 'sig/client.rbs', line 816
def list_signal_catalogs: (
|
#list_state_templates(params = {}) ⇒ Types::ListStateTemplatesResponse
Lists information about created state templates.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
828 |
# File 'sig/client.rbs', line 828
def list_state_templates: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
840 |
# File 'sig/client.rbs', line 840
def list_tags_for_resource: (
|
#list_vehicles(params = {}) ⇒ Types::ListVehiclesResponse
Retrieves a list of summaries of created vehicles.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
851 |
# File 'sig/client.rbs', line 851
def list_vehicles: (
|
#list_vehicles_in_fleet(params = {}) ⇒ Types::ListVehiclesInFleetResponse
Retrieves a list of summaries of all vehicles associated with a fleet.
nextToken parameter
in the request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
867 |
# File 'sig/client.rbs', line 867
def list_vehicles_in_fleet: (
|
#put_encryption_configuration(params = {}) ⇒ Types::PutEncryptionConfigurationResponse
Creates or updates the encryption configuration. Amazon Web Services IoT FleetWise can encrypt your data and resources using an Amazon Web Services managed key. Or, you can use a KMS key that you own and manage. For more information, see Data encryption in the Amazon Web Services IoT FleetWise Developer Guide.
881 |
# File 'sig/client.rbs', line 881
def put_encryption_configuration: (
|
#put_logging_options(params = {}) ⇒ Struct
Creates or updates the logging option.
891 |
# File 'sig/client.rbs', line 891
def put_logging_options: (
|
#register_account(params = {}) ⇒ Types::RegisterAccountResponse
This API operation contains deprecated parameters. Register your account again without the Timestream resources parameter so that Amazon Web Services IoT FleetWise can remove the Timestream metadata stored. You should then pass the data destination into the CreateCampaign API operation.
You must delete any existing campaigns that include an empty data destination before you register your account again. For more information, see the DeleteCampaign API operation.
If you want to delete the Timestream inline policy from the service-linked role, such as to mitigate an overly permissive policy, you must first delete any existing campaigns. Then delete the service-linked role and register your account again to enable CloudWatch metrics. For more information, see DeleteServiceLinkedRole in the Identity and Access Management API Reference.
Registers your Amazon Web Services account, IAM, and Amazon Timestream resources so Amazon Web Services IoT FleetWise can transfer your vehicle data to the Amazon Web Services Cloud. For more information, including step-by-step procedures, see Setting up Amazon Web Services IoT FleetWise.
908 |
# File 'sig/client.rbs', line 908
def register_account: (
|
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource.
923 |
# File 'sig/client.rbs', line 923
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the given tags (metadata) from the resource.
938 |
# File 'sig/client.rbs', line 938
def untag_resource: (
|
#update_campaign(params = {}) ⇒ Types::UpdateCampaignResponse
Updates a campaign.
951 |
# File 'sig/client.rbs', line 951
def update_campaign: (
|
#update_decoder_manifest(params = {}) ⇒ Types::UpdateDecoderManifestResponse
Updates a decoder manifest.
A decoder manifest can only be updated when the status is DRAFT.
Only ACTIVE decoder manifests can be associated with vehicles.
965 |
# File 'sig/client.rbs', line 965
def update_decoder_manifest: (
|
#update_fleet(params = {}) ⇒ Types::UpdateFleetResponse
Updates the description of an existing fleet.
993 |
# File 'sig/client.rbs', line 993
def update_fleet: (
|
#update_model_manifest(params = {}) ⇒ Types::UpdateModelManifestResponse
Updates a vehicle model (model manifest). If created vehicles are associated with a vehicle model, it can't be updated.
1005 |
# File 'sig/client.rbs', line 1005
def update_model_manifest: (
|
#update_signal_catalog(params = {}) ⇒ Types::UpdateSignalCatalogResponse
Updates a signal catalog.
1020 |
# File 'sig/client.rbs', line 1020
def update_signal_catalog: (
|
#update_state_template(params = {}) ⇒ Types::UpdateStateTemplateResponse
Updates a state template.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.
1040 |
# File 'sig/client.rbs', line 1040
def update_state_template: (
|
#update_vehicle(params = {}) ⇒ Types::UpdateVehicleResponse
Updates a vehicle.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.
1056 |
# File 'sig/client.rbs', line 1056
def update_vehicle: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4261 4262 4263 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4261 def waiter_names [] end |