Class: Aws::IoTFleetWise::Types::Actuator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleetwise/types.rb

Overview

A signal that represents a vehicle device such as the engine, heater, and door locks. Data from an actuator reports the state of a certain vehicle device.

Updating actuator data can change the state of a device. For example, you can turn on or off the heater by updating its actuator data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_values ⇒ Array<String>

A list of possible values an actuator can take.

Returns:

  • (Array<String>)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#assigned_value ⇒ String

A specified value for the actuator.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#comment ⇒ String

A comment in addition to the description.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#data_type ⇒ String

The specified data type of the actuator.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#deprecation_message ⇒ String

The deprecation message for the node or the branch that was moved or deleted.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A brief description of the actuator.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#fully_qualified_name ⇒ String

The fully qualified name of the actuator. For example, the fully qualified name of an actuator might be Vehicle.Front.Left.Door.Lock.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#max ⇒ Float

The specified possible maximum value of an actuator.

Returns:

  • (Float)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#min ⇒ Float

The specified possible minimum value of an actuator.

Returns:

  • (Float)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#struct_fully_qualified_name ⇒ String

The fully qualified name of the struct node for the actuator if the data type of the actuator is Struct or StructArray. For example, the struct fully qualified name of an actuator might be Vehicle.Door.LockStruct.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end

#unit ⇒ String

The scientific unit for the actuator.

Returns:

  • (String)


83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 83

class Actuator < Struct.new(
  :fully_qualified_name,
  :data_type,
  :description,
  :unit,
  :allowed_values,
  :min,
  :max,
  :assigned_value,
  :deprecation_message,
  :comment,
  :struct_fully_qualified_name)
  SENSITIVE = []
  include Aws::Structure
end