Class: Aws::IoTFleetWise::Types::CanSignal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleetwise/types.rb

Overview

Information about a single controller area network (CAN) signal and the messages it receives and transmits.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#factor ⇒ Float

A multiplier used to decode the CAN message.

Returns:

  • (Float)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#is_big_endian ⇒ Boolean

Whether the byte ordering of a CAN message is big-endian.

Returns:

  • (Boolean)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#is_signed ⇒ Boolean

Determines whether the message is signed (true) or not (false). If it's signed, the message can represent both positive and negative numbers. The isSigned parameter only applies to the INTEGER raw signal type, and it doesn't affect the FLOATING_POINT raw signal type.

Returns:

  • (Boolean)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#length ⇒ Integer

How many bytes of data are in the message.

Returns:

  • (Integer)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#message_id ⇒ Integer

The ID of the message.

Returns:

  • (Integer)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the signal.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#offset ⇒ Float

The offset used to calculate the signal value. Combined with factor, the calculation is value = raw_value * factor + offset.

Returns:

  • (Float)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#signal_value_type ⇒ String

The value type of the signal. The default value is INTEGER.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end

#start_bit ⇒ Integer

Indicates the beginning of the CAN signal. This should always be the least significant bit (LSB).

This value might be different from the value in a DBC file. For little endian signals, startBit is the same value as in the DBC file. For big endian signals in a DBC file, the start bit is the most significant bit (MSB). You will have to calculate the LSB instead and pass it as the startBit.

Returns:

  • (Integer)


431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 431

class CanSignal < Struct.new(
  :message_id,
  :is_big_endian,
  :is_signed,
  :start_bit,
  :offset,
  :factor,
  :length,
  :name,
  :signal_value_type)
  SENSITIVE = []
  include Aws::Structure
end