Class: Aws::IoTFleetWise::Types::CreateSignalCatalogRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleetwise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

A brief description of the signal catalog.

Returns:

  • (String)


913
914
915
916
917
918
919
920
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 913

class CreateSignalCatalogRequest < Struct.new(
  :name,
  :description,
  :nodes,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the signal catalog to create.

Returns:

  • (String)


913
914
915
916
917
918
919
920
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 913

class CreateSignalCatalogRequest < Struct.new(
  :name,
  :description,
  :nodes,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nodes ⇒ Array<Types::Node>

A list of information about nodes, which are a general abstraction of signals. For more information, see the API data type.

Returns:



913
914
915
916
917
918
919
920
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 913

class CreateSignalCatalogRequest < Struct.new(
  :name,
  :description,
  :nodes,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

Metadata that can be used to manage the signal catalog.

Returns:



913
914
915
916
917
918
919
920
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 913

class CreateSignalCatalogRequest < Struct.new(
  :name,
  :description,
  :nodes,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end