Class: Aws::IoTFleetWise::Types::ListCampaignsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTFleetWise::Types::ListCampaignsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotfleetwise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#list_response_scope ⇒ String
When you set the
listResponseScopeparameter toMETADATA_ONLY, the list response includes: campaign name, Amazon Resource Name (ARN), creation time, and last modification time. -
#max_results ⇒ Integer
The maximum number of items to return, between 1 and 100, inclusive.
-
#next_token ⇒ String
A pagination token for the next set of results.
-
#status ⇒ String
An optional parameter to filter the results by the status of each created campaign in your account.
Instance Attribute Details
#list_response_scope ⇒ String
When you set the listResponseScope parameter to METADATA_ONLY,
the list response includes: campaign name, Amazon Resource Name
(ARN), creation time, and last modification time.
2730 2731 2732 2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2730 class ListCampaignsRequest < Struct.new( :next_token, :max_results, :status, :list_response_scope) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return, between 1 and 100, inclusive.
2730 2731 2732 2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2730 class ListCampaignsRequest < Struct.new( :next_token, :max_results, :status, :list_response_scope) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token for the next set of results.
If the results of a search are large, only a portion of the results
are returned, and a nextToken pagination token is returned in the
response. To retrieve the next set of results, reissue the search
request and include the returned token. When all results have been
returned, the response does not contain a pagination token value.
2730 2731 2732 2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2730 class ListCampaignsRequest < Struct.new( :next_token, :max_results, :status, :list_response_scope) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
An optional parameter to filter the results by the status of each
created campaign in your account. The status can be one of:
CREATING, WAITING_FOR_APPROVAL, RUNNING, or SUSPENDED.
2730 2731 2732 2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2730 class ListCampaignsRequest < Struct.new( :next_token, :max_results, :status, :list_response_scope) SENSITIVE = [] include Aws::Structure end |