Class: Aws::IoTFleetWise::Types::ListDecoderManifestSignalsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleetwise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of items to return, between 1 and 100, inclusive.

Returns:

  • (Integer)


2815
2816
2817
2818
2819
2820
2821
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2815

class ListDecoderManifestSignalsRequest < Struct.new(
  :name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the decoder manifest to list information about.

Returns:

  • (String)


2815
2816
2817
2818
2819
2820
2821
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2815

class ListDecoderManifestSignalsRequest < Struct.new(
  :name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A pagination token for the next set of results.

If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next set of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

Returns:

  • (String)


2815
2816
2817
2818
2819
2820
2821
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2815

class ListDecoderManifestSignalsRequest < Struct.new(
  :name,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end