Class: Aws::IoTFleetWise::Types::ListDecoderManifestsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTFleetWise::Types::ListDecoderManifestsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotfleetwise/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#list_response_scope ⇒ String
When you set the
listResponseScopeparameter toMETADATA_ONLY, the list response includes: decoder manifest name, Amazon Resource Name (ARN), creation time, and last modification time. -
#max_results ⇒ Integer
The maximum number of items to return, between 1 and 100, inclusive.
-
#model_manifest_arn ⇒ String
The Amazon Resource Name (ARN) of a vehicle model (model manifest) associated with the decoder manifest.
-
#next_token ⇒ String
A pagination token for the next set of results.
Instance Attribute Details
#list_response_scope ⇒ String
When you set the listResponseScope parameter to METADATA_ONLY,
the list response includes: decoder manifest name, Amazon Resource
Name (ARN), creation time, and last modification time.
2864 2865 2866 2867 2868 2869 2870 2871 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2864 class ListDecoderManifestsRequest < Struct.new( :model_manifest_arn, :next_token, :max_results, :list_response_scope) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return, between 1 and 100, inclusive.
2864 2865 2866 2867 2868 2869 2870 2871 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2864 class ListDecoderManifestsRequest < Struct.new( :model_manifest_arn, :next_token, :max_results, :list_response_scope) SENSITIVE = [] include Aws::Structure end |
#model_manifest_arn ⇒ String
The Amazon Resource Name (ARN) of a vehicle model (model manifest) associated with the decoder manifest.
2864 2865 2866 2867 2868 2869 2870 2871 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2864 class ListDecoderManifestsRequest < Struct.new( :model_manifest_arn, :next_token, :max_results, :list_response_scope) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token for the next set of results.
If the results of a search are large, only a portion of the results
are returned, and a nextToken pagination token is returned in the
response. To retrieve the next set of results, reissue the search
request and include the returned token. When all results have been
returned, the response does not contain a pagination token value.
2864 2865 2866 2867 2868 2869 2870 2871 |
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 2864 class ListDecoderManifestsRequest < Struct.new( :model_manifest_arn, :next_token, :max_results, :list_response_scope) SENSITIVE = [] include Aws::Structure end |