Class: Aws::IoTFleetWise::Types::ListVehiclesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleetwise/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_names ⇒ Array<String>

The fully qualified names of the attributes. You can use this optional parameter to list the vehicles containing all the attributes in the request. For example, attributeNames could be "Vehicle.Body.Engine.Type, Vehicle.Color" and the corresponding attributeValues could be "1.3 L R2, Blue" . In this case, the API will filter vehicles with an attribute name Vehicle.Body.Engine.Type that contains a value of 1.3 L R2 AND an attribute name Vehicle.Color that contains a value of "Blue". A request must contain unique values for the attributeNames filter and the matching number of attributeValues filters to return the subset of vehicles that match the attributes filter condition.

Returns:

  • (Array<String>)


3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3309

class ListVehiclesRequest < Struct.new(
  :model_manifest_arn,
  :attribute_names,
  :attribute_values,
  :next_token,
  :max_results,
  :list_response_scope)
  SENSITIVE = []
  include Aws::Structure
end

#attribute_values ⇒ Array<String>

Static information about a vehicle attribute value in string format. You can use this optional parameter in conjunction with attributeNames to list the vehicles containing all the attributeValues corresponding to the attributeNames filter. For example, attributeValues could be "1.3 L R2, Blue" and the corresponding attributeNames filter could be "Vehicle.Body.Engine.Type, Vehicle.Color". In this case, the API will filter vehicles with attribute name Vehicle.Body.Engine.Type that contains a value of 1.3 L R2 AND an attribute name Vehicle.Color that contains a value of "Blue". A request must contain unique values for the attributeNames filter and the matching number of attributeValues filter to return the subset of vehicles that match the attributes filter condition.

Returns:

  • (Array<String>)


3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3309

class ListVehiclesRequest < Struct.new(
  :model_manifest_arn,
  :attribute_names,
  :attribute_values,
  :next_token,
  :max_results,
  :list_response_scope)
  SENSITIVE = []
  include Aws::Structure
end

#list_response_scope ⇒ String

When you set the listResponseScope parameter to METADATA_ONLY, the list response includes: vehicle name, Amazon Resource Name (ARN), creation time, and last modification time.

Returns:

  • (String)


3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3309

class ListVehiclesRequest < Struct.new(
  :model_manifest_arn,
  :attribute_names,
  :attribute_values,
  :next_token,
  :max_results,
  :list_response_scope)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return, between 1 and 100, inclusive.

Returns:

  • (Integer)


3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3309

class ListVehiclesRequest < Struct.new(
  :model_manifest_arn,
  :attribute_names,
  :attribute_values,
  :next_token,
  :max_results,
  :list_response_scope)
  SENSITIVE = []
  include Aws::Structure
end

#model_manifest_arn ⇒ String

The Amazon Resource Name (ARN) of a vehicle model (model manifest). You can use this optional parameter to list only the vehicles created from a certain vehicle model.

Returns:

  • (String)


3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3309

class ListVehiclesRequest < Struct.new(
  :model_manifest_arn,
  :attribute_names,
  :attribute_values,
  :next_token,
  :max_results,
  :list_response_scope)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A pagination token for the next set of results.

If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next set of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

Returns:

  • (String)


3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3309

class ListVehiclesRequest < Struct.new(
  :model_manifest_arn,
  :attribute_names,
  :attribute_values,
  :next_token,
  :max_results,
  :list_response_scope)
  SENSITIVE = []
  include Aws::Structure
end