Class: Aws::IoTFleetWise::Types::ObdInterface

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleetwise/types.rb

Overview

A network interface that specifies the on-board diagnostic (OBD) II network protocol.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dtc_request_interval_seconds ⇒ Integer

The maximum number message requests per diagnostic trouble code per second.

Returns:

  • (Integer)


3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3658

class ObdInterface < Struct.new(
  :name,
  :request_message_id,
  :obd_standard,
  :pid_request_interval_seconds,
  :dtc_request_interval_seconds,
  :use_extended_ids,
  :has_transmission_ecu)
  SENSITIVE = []
  include Aws::Structure
end

#has_transmission_ecu ⇒ Boolean

Whether the vehicle has a transmission control module (TCM).

Returns:

  • (Boolean)


3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3658

class ObdInterface < Struct.new(
  :name,
  :request_message_id,
  :obd_standard,
  :pid_request_interval_seconds,
  :dtc_request_interval_seconds,
  :use_extended_ids,
  :has_transmission_ecu)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the interface.

Returns:

  • (String)


3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3658

class ObdInterface < Struct.new(
  :name,
  :request_message_id,
  :obd_standard,
  :pid_request_interval_seconds,
  :dtc_request_interval_seconds,
  :use_extended_ids,
  :has_transmission_ecu)
  SENSITIVE = []
  include Aws::Structure
end

#obd_standard ⇒ String

The standard OBD II PID.

Returns:

  • (String)


3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3658

class ObdInterface < Struct.new(
  :name,
  :request_message_id,
  :obd_standard,
  :pid_request_interval_seconds,
  :dtc_request_interval_seconds,
  :use_extended_ids,
  :has_transmission_ecu)
  SENSITIVE = []
  include Aws::Structure
end

#pid_request_interval_seconds ⇒ Integer

The maximum number message requests per second.

Returns:

  • (Integer)


3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3658

class ObdInterface < Struct.new(
  :name,
  :request_message_id,
  :obd_standard,
  :pid_request_interval_seconds,
  :dtc_request_interval_seconds,
  :use_extended_ids,
  :has_transmission_ecu)
  SENSITIVE = []
  include Aws::Structure
end

#request_message_id ⇒ Integer

The ID of the message requesting vehicle data.

Returns:

  • (Integer)


3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3658

class ObdInterface < Struct.new(
  :name,
  :request_message_id,
  :obd_standard,
  :pid_request_interval_seconds,
  :dtc_request_interval_seconds,
  :use_extended_ids,
  :has_transmission_ecu)
  SENSITIVE = []
  include Aws::Structure
end

#use_extended_ids ⇒ Boolean

Whether to use extended IDs in the message.

Returns:

  • (Boolean)


3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 3658

class ObdInterface < Struct.new(
  :name,
  :request_message_id,
  :obd_standard,
  :pid_request_interval_seconds,
  :dtc_request_interval_seconds,
  :use_extended_ids,
  :has_transmission_ecu)
  SENSITIVE = []
  include Aws::Structure
end