Class: Aws::IoTFleetWise::Types::SignalInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleetwise/types.rb

Overview

Information about a signal.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_partition_id ⇒ String

The ID of the data partition this signal is associated with.

The ID must match one of the IDs provided in dataPartitions. This is accomplished either by specifying a particular data partition ID or by using default for an established default partition. You can establish a default partition in the DataPartition data type.

If you upload a signal as a condition for a campaign's data partition, the same signal must be included in signalsToCollect.

Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see Amazon Web Services Region and feature availability in the Amazon Web Services IoT FleetWise Developer Guide.

Returns:

  • (String)


4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 4270

class SignalInformation < Struct.new(
  :name,
  :max_sample_count,
  :minimum_sampling_interval_ms,
  :data_partition_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_sample_count ⇒ Integer

The maximum number of samples to collect.

Returns:

  • (Integer)


4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 4270

class SignalInformation < Struct.new(
  :name,
  :max_sample_count,
  :minimum_sampling_interval_ms,
  :data_partition_id)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_sampling_interval_ms ⇒ Integer

The minimum duration of time (in milliseconds) between two triggering events to collect data.

If a signal changes often, you might want to collect data at a slower rate.

Returns:

  • (Integer)


4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 4270

class SignalInformation < Struct.new(
  :name,
  :max_sample_count,
  :minimum_sampling_interval_ms,
  :data_partition_id)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the signal.

Returns:

  • (String)


4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/aws-sdk-iotfleetwise/types.rb', line 4270

class SignalInformation < Struct.new(
  :name,
  :max_sample_count,
  :minimum_sampling_interval_ms,
  :data_partition_id)
  SENSITIVE = []
  include Aws::Structure
end