Class: Aws::IoTFleetWise::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTFleetWise::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotfleetwise/client.rb
Overview
An API client for IoTFleetWise. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTFleetWise::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_vehicle_fleet(params = {}) ⇒ Struct
Adds, or associates, a vehicle with a fleet.
-
#batch_create_vehicle(params = {}) ⇒ Types::BatchCreateVehicleResponse
Creates a group, or batch, of vehicles.
-
#batch_update_vehicle(params = {}) ⇒ Types::BatchUpdateVehicleResponse
Updates a group, or batch, of vehicles.
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates an orchestration of data collection rules.
-
#create_decoder_manifest(params = {}) ⇒ Types::CreateDecoderManifestResponse
Creates the decoder manifest associated with a model manifest.
-
#create_fleet(params = {}) ⇒ Types::CreateFleetResponse
Creates a fleet that represents a group of vehicles.
-
#create_model_manifest(params = {}) ⇒ Types::CreateModelManifestResponse
Creates a vehicle model (model manifest) that specifies signals (attributes, branches, sensors, and actuators).
-
#create_signal_catalog(params = {}) ⇒ Types::CreateSignalCatalogResponse
Creates a collection of standardized signals that can be reused to create vehicle models.
-
#create_state_template(params = {}) ⇒ Types::CreateStateTemplateResponse
Creates a state template.
-
#create_vehicle(params = {}) ⇒ Types::CreateVehicleResponse
Creates a vehicle, which is an instance of a vehicle model (model manifest).
-
#delete_campaign(params = {}) ⇒ Types::DeleteCampaignResponse
Deletes a data collection campaign.
-
#delete_decoder_manifest(params = {}) ⇒ Types::DeleteDecoderManifestResponse
Deletes a decoder manifest.
-
#delete_fleet(params = {}) ⇒ Types::DeleteFleetResponse
Deletes a fleet.
-
#delete_model_manifest(params = {}) ⇒ Types::DeleteModelManifestResponse
Deletes a vehicle model (model manifest).
-
#delete_signal_catalog(params = {}) ⇒ Types::DeleteSignalCatalogResponse
Deletes a signal catalog.
-
#delete_state_template(params = {}) ⇒ Types::DeleteStateTemplateResponse
Deletes a state template.
-
#delete_vehicle(params = {}) ⇒ Types::DeleteVehicleResponse
Deletes a vehicle and removes it from any campaigns.
-
#disassociate_vehicle_fleet(params = {}) ⇒ Struct
Removes, or disassociates, a vehicle from a fleet.
-
#get_campaign(params = {}) ⇒ Types::GetCampaignResponse
Retrieves information about a campaign.
-
#get_decoder_manifest(params = {}) ⇒ Types::GetDecoderManifestResponse
Retrieves information about a created decoder manifest.
-
#get_encryption_configuration(params = {}) ⇒ Types::GetEncryptionConfigurationResponse
Retrieves the encryption configuration for resources and data in Amazon Web Services IoT FleetWise.
-
#get_fleet(params = {}) ⇒ Types::GetFleetResponse
Retrieves information about a fleet.
-
#get_logging_options(params = {}) ⇒ Types::GetLoggingOptionsResponse
Retrieves the logging options.
-
#get_model_manifest(params = {}) ⇒ Types::GetModelManifestResponse
Retrieves information about a vehicle model (model manifest).
-
#get_register_account_status(params = {}) ⇒ Types::GetRegisterAccountStatusResponse
Retrieves information about the status of registering your Amazon Web Services account, IAM, and Amazon Timestream resources so that Amazon Web Services IoT FleetWise can transfer your vehicle data to the Amazon Web Services Cloud.
-
#get_signal_catalog(params = {}) ⇒ Types::GetSignalCatalogResponse
Retrieves information about a signal catalog.
-
#get_state_template(params = {}) ⇒ Types::GetStateTemplateResponse
Retrieves information about a state template.
-
#get_vehicle(params = {}) ⇒ Types::GetVehicleResponse
Retrieves information about a vehicle.
-
#get_vehicle_status(params = {}) ⇒ Types::GetVehicleStatusResponse
Retrieves information about the status of campaigns, decoder manifests, or state templates associated with a vehicle.
-
#import_decoder_manifest(params = {}) ⇒ Types::ImportDecoderManifestResponse
Creates a decoder manifest using your existing CAN DBC file from your local device.
-
#import_signal_catalog(params = {}) ⇒ Types::ImportSignalCatalogResponse
Creates a signal catalog using your existing VSS formatted content from your local device.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Lists information about created campaigns.
-
#list_decoder_manifest_network_interfaces(params = {}) ⇒ Types::ListDecoderManifestNetworkInterfacesResponse
Lists the network interfaces specified in a decoder manifest.
-
#list_decoder_manifest_signals(params = {}) ⇒ Types::ListDecoderManifestSignalsResponse
A list of information about signal decoders specified in a decoder manifest.
-
#list_decoder_manifests(params = {}) ⇒ Types::ListDecoderManifestsResponse
Lists decoder manifests.
-
#list_fleets(params = {}) ⇒ Types::ListFleetsResponse
Retrieves information for each created fleet in an Amazon Web Services account.
-
#list_fleets_for_vehicle(params = {}) ⇒ Types::ListFleetsForVehicleResponse
Retrieves a list of IDs for all fleets that the vehicle is associated with.
-
#list_model_manifest_nodes(params = {}) ⇒ Types::ListModelManifestNodesResponse
Lists information about nodes specified in a vehicle model (model manifest).
-
#list_model_manifests(params = {}) ⇒ Types::ListModelManifestsResponse
Retrieves a list of vehicle models (model manifests).
-
#list_signal_catalog_nodes(params = {}) ⇒ Types::ListSignalCatalogNodesResponse
Lists of information about the signals (nodes) specified in a signal catalog.
-
#list_signal_catalogs(params = {}) ⇒ Types::ListSignalCatalogsResponse
Lists all the created signal catalogs in an Amazon Web Services account.
-
#list_state_templates(params = {}) ⇒ Types::ListStateTemplatesResponse
Lists information about created state templates.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
-
#list_vehicles(params = {}) ⇒ Types::ListVehiclesResponse
Retrieves a list of summaries of created vehicles.
-
#list_vehicles_in_fleet(params = {}) ⇒ Types::ListVehiclesInFleetResponse
Retrieves a list of summaries of all vehicles associated with a fleet.
-
#put_encryption_configuration(params = {}) ⇒ Types::PutEncryptionConfigurationResponse
Creates or updates the encryption configuration.
-
#put_logging_options(params = {}) ⇒ Struct
Creates or updates the logging option.
-
#register_account(params = {}) ⇒ Types::RegisterAccountResponse
This API operation contains deprecated parameters.
-
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the given tags (metadata) from the resource.
-
#update_campaign(params = {}) ⇒ Types::UpdateCampaignResponse
Updates a campaign.
-
#update_decoder_manifest(params = {}) ⇒ Types::UpdateDecoderManifestResponse
Updates a decoder manifest.
-
#update_fleet(params = {}) ⇒ Types::UpdateFleetResponse
Updates the description of an existing fleet.
-
#update_model_manifest(params = {}) ⇒ Types::UpdateModelManifestResponse
Updates a vehicle model (model manifest).
-
#update_signal_catalog(params = {}) ⇒ Types::UpdateSignalCatalogResponse
Updates a signal catalog.
-
#update_state_template(params = {}) ⇒ Types::UpdateStateTemplateResponse
Updates a state template.
-
#update_vehicle(params = {}) ⇒ Types::UpdateVehicleResponse
Updates a vehicle.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4268 4269 4270 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4268 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4271 4272 4273 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4271 def errors_module Errors end |
Instance Method Details
#associate_vehicle_fleet(params = {}) ⇒ Struct
Adds, or associates, a vehicle with a fleet.
503 504 505 506 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 503 def associate_vehicle_fleet(params = {}, = {}) req = build_request(:associate_vehicle_fleet, params) req.send_request() end |
#batch_create_vehicle(params = {}) ⇒ Types::BatchCreateVehicleResponse
Creates a group, or batch, of vehicles.
<note markdown=“1”> You must specify a decoder manifest and a vehicle model (model manifest) for each vehicle.
</note>
For more information, see [Create multiple vehicles (AWS CLI)] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/create-vehicles-cli.html
581 582 583 584 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 581 def batch_create_vehicle(params = {}, = {}) req = build_request(:batch_create_vehicle, params) req.send_request() end |
#batch_update_vehicle(params = {}) ⇒ Types::BatchUpdateVehicleResponse
Updates a group, or batch, of vehicles.
<note markdown=“1”> You must specify a decoder manifest and a vehicle model (model manifest) for each vehicle.
</note>
For more information, see [Update multiple vehicles (AWS CLI)] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/update-vehicles-cli.html
668 669 670 671 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 668 def batch_update_vehicle(params = {}, = {}) req = build_request(:batch_update_vehicle, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4241 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTFleetWise') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotfleetwise' context[:gem_version] = '1.64.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates an orchestration of data collection rules. The Amazon Web Services IoT FleetWise Edge Agent software running in vehicles uses campaigns to decide how to collect and transfer data to the cloud. You create campaigns in the cloud. After you or your team approve campaigns, Amazon Web Services IoT FleetWise automatically deploys them to vehicles.
For more information, see [Collect and transfer data with campaigns] in the *Amazon Web Services IoT FleetWise Developer Guide*.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see [Amazon Web Services Region and feature availability] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/campaigns.html [2]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleetwise-regions.html
917 918 919 920 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 917 def create_campaign(params = {}, = {}) req = build_request(:create_campaign, params) req.send_request() end |
#create_decoder_manifest(params = {}) ⇒ Types::CreateDecoderManifestResponse
Creates the decoder manifest associated with a model manifest. To create a decoder manifest, the following must be true:
-
Every signal decoder has a unique name.
-
Each signal decoder is associated with a network interface.
-
Each network interface has a unique ID.
-
The signal decoders are specified in the model manifest.
1081 1082 1083 1084 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1081 def create_decoder_manifest(params = {}, = {}) req = build_request(:create_decoder_manifest, params) req.send_request() end |
#create_fleet(params = {}) ⇒ Types::CreateFleetResponse
Creates a fleet that represents a group of vehicles.
<note markdown=“1”> You must create both a signal catalog and vehicles before you can create a fleet.
</note>
For more information, see [Fleets] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleets.html
1138 1139 1140 1141 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1138 def create_fleet(params = {}, = {}) req = build_request(:create_fleet, params) req.send_request() end |
#create_model_manifest(params = {}) ⇒ Types::CreateModelManifestResponse
Creates a vehicle model (model manifest) that specifies signals (attributes, branches, sensors, and actuators).
For more information, see [Vehicle models] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/vehicle-models.html
1195 1196 1197 1198 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1195 def create_model_manifest(params = {}, = {}) req = build_request(:create_model_manifest, params) req.send_request() end |
#create_signal_catalog(params = {}) ⇒ Types::CreateSignalCatalogResponse
Creates a collection of standardized signals that can be reused to create vehicle models.
1304 1305 1306 1307 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1304 def create_signal_catalog(params = {}, = {}) req = build_request(:create_signal_catalog, params) req.send_request() end |
#create_state_template(params = {}) ⇒ Types::CreateStateTemplateResponse
Creates a state template. State templates contain state properties, which are signals that belong to a signal catalog that is synchronized between the Amazon Web Services IoT FleetWise Edge and the Amazon Web Services Cloud.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see [Amazon Web Services Region and feature availability] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleetwise-regions.html
1397 1398 1399 1400 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1397 def create_state_template(params = {}, = {}) req = build_request(:create_state_template, params) req.send_request() end |
#create_vehicle(params = {}) ⇒ Types::CreateVehicleResponse
Creates a vehicle, which is an instance of a vehicle model (model manifest). Vehicles created from the same vehicle model consist of the same signals inherited from the vehicle model.
<note markdown=“1”> If you have an existing Amazon Web Services IoT thing, you can use Amazon Web Services IoT FleetWise to create a vehicle and collect data from your thing.
</note>
For more information, see [Create a vehicle (AWS CLI)] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/create-vehicle-cli.html
1498 1499 1500 1501 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1498 def create_vehicle(params = {}, = {}) req = build_request(:create_vehicle, params) req.send_request() end |
#delete_campaign(params = {}) ⇒ Types::DeleteCampaignResponse
Deletes a data collection campaign. Deleting a campaign suspends all data collection and removes it from any vehicles.
1527 1528 1529 1530 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1527 def delete_campaign(params = {}, = {}) req = build_request(:delete_campaign, params) req.send_request() end |
#delete_decoder_manifest(params = {}) ⇒ Types::DeleteDecoderManifestResponse
Deletes a decoder manifest. You can’t delete a decoder manifest if it has vehicles associated with it.
1556 1557 1558 1559 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1556 def delete_decoder_manifest(params = {}, = {}) req = build_request(:delete_decoder_manifest, params) req.send_request() end |
#delete_fleet(params = {}) ⇒ Types::DeleteFleetResponse
Deletes a fleet. Before you delete a fleet, all vehicles must be dissociated from the fleet. For more information, see [Delete a fleet (AWS CLI)] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/delete-fleet-cli.html
1591 1592 1593 1594 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1591 def delete_fleet(params = {}, = {}) req = build_request(:delete_fleet, params) req.send_request() end |
#delete_model_manifest(params = {}) ⇒ Types::DeleteModelManifestResponse
Deletes a vehicle model (model manifest).
1619 1620 1621 1622 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1619 def delete_model_manifest(params = {}, = {}) req = build_request(:delete_model_manifest, params) req.send_request() end |
#delete_signal_catalog(params = {}) ⇒ Types::DeleteSignalCatalogResponse
Deletes a signal catalog.
1647 1648 1649 1650 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1647 def delete_signal_catalog(params = {}, = {}) req = build_request(:delete_signal_catalog, params) req.send_request() end |
#delete_state_template(params = {}) ⇒ Types::DeleteStateTemplateResponse
Deletes a state template.
1677 1678 1679 1680 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1677 def delete_state_template(params = {}, = {}) req = build_request(:delete_state_template, params) req.send_request() end |
#delete_vehicle(params = {}) ⇒ Types::DeleteVehicleResponse
Deletes a vehicle and removes it from any campaigns.
1705 1706 1707 1708 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1705 def delete_vehicle(params = {}, = {}) req = build_request(:delete_vehicle, params) req.send_request() end |
#disassociate_vehicle_fleet(params = {}) ⇒ Struct
Removes, or disassociates, a vehicle from a fleet. Disassociating a vehicle from a fleet doesn’t delete the vehicle.
1730 1731 1732 1733 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1730 def disassociate_vehicle_fleet(params = {}, = {}) req = build_request(:disassociate_vehicle_fleet, params) req.send_request() end |
#get_campaign(params = {}) ⇒ Types::GetCampaignResponse
Retrieves information about a campaign.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see [Amazon Web Services Region and feature availability] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleetwise-regions.html
1837 1838 1839 1840 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1837 def get_campaign(params = {}, = {}) req = build_request(:get_campaign, params) req.send_request() end |
#get_decoder_manifest(params = {}) ⇒ Types::GetDecoderManifestResponse
Retrieves information about a created decoder manifest.
1877 1878 1879 1880 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1877 def get_decoder_manifest(params = {}, = {}) req = build_request(:get_decoder_manifest, params) req.send_request() end |
#get_encryption_configuration(params = {}) ⇒ Types::GetEncryptionConfigurationResponse
Retrieves the encryption configuration for resources and data in Amazon Web Services IoT FleetWise.
1905 1906 1907 1908 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1905 def get_encryption_configuration(params = {}, = {}) req = build_request(:get_encryption_configuration, params) req.send_request() end |
#get_fleet(params = {}) ⇒ Types::GetFleetResponse
Retrieves information about a fleet.
1941 1942 1943 1944 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1941 def get_fleet(params = {}, = {}) req = build_request(:get_fleet, params) req.send_request() end |
#get_logging_options(params = {}) ⇒ Types::GetLoggingOptionsResponse
Retrieves the logging options.
1959 1960 1961 1962 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1959 def (params = {}, = {}) req = build_request(:get_logging_options, params) req.send_request() end |
#get_model_manifest(params = {}) ⇒ Types::GetModelManifestResponse
Retrieves information about a vehicle model (model manifest).
1997 1998 1999 2000 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 1997 def get_model_manifest(params = {}, = {}) req = build_request(:get_model_manifest, params) req.send_request() end |
#get_register_account_status(params = {}) ⇒ Types::GetRegisterAccountStatusResponse
Retrieves information about the status of registering your Amazon Web Services account, IAM, and Amazon Timestream resources so that Amazon Web Services IoT FleetWise can transfer your vehicle data to the Amazon Web Services Cloud.
For more information, including step-by-step procedures, see [Setting up Amazon Web Services IoT FleetWise].
<note markdown=“1”> This API operation doesn’t require input parameters.
</note>
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/setting-up.html
2045 2046 2047 2048 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2045 def get_register_account_status(params = {}, = {}) req = build_request(:get_register_account_status, params) req.send_request() end |
#get_signal_catalog(params = {}) ⇒ Types::GetSignalCatalogResponse
Retrieves information about a signal catalog.
2087 2088 2089 2090 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2087 def get_signal_catalog(params = {}, = {}) req = build_request(:get_signal_catalog, params) req.send_request() end |
#get_state_template(params = {}) ⇒ Types::GetStateTemplateResponse
Retrieves information about a state template.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see [Amazon Web Services Region and feature availability] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleetwise-regions.html
2143 2144 2145 2146 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2143 def get_state_template(params = {}, = {}) req = build_request(:get_state_template, params) req.send_request() end |
#get_vehicle(params = {}) ⇒ Types::GetVehicleResponse
Retrieves information about a vehicle.
2187 2188 2189 2190 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2187 def get_vehicle(params = {}, = {}) req = build_request(:get_vehicle, params) req.send_request() end |
#get_vehicle_status(params = {}) ⇒ Types::GetVehicleStatusResponse
Retrieves information about the status of campaigns, decoder manifests, or state templates associated with a vehicle.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2237 2238 2239 2240 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2237 def get_vehicle_status(params = {}, = {}) req = build_request(:get_vehicle_status, params) req.send_request() end |
#import_decoder_manifest(params = {}) ⇒ Types::ImportDecoderManifestResponse
Creates a decoder manifest using your existing CAN DBC file from your local device.
The CAN signal name must be unique and not repeated across CAN message definitions in a .dbc file.
2283 2284 2285 2286 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2283 def import_decoder_manifest(params = {}, = {}) req = build_request(:import_decoder_manifest, params) req.send_request() end |
#import_signal_catalog(params = {}) ⇒ Types::ImportSignalCatalogResponse
Creates a signal catalog using your existing VSS formatted content from your local device.
2333 2334 2335 2336 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2333 def import_signal_catalog(params = {}, = {}) req = build_request(:import_signal_catalog, params) req.send_request() end |
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Lists information about created campaigns.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2398 2399 2400 2401 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2398 def list_campaigns(params = {}, = {}) req = build_request(:list_campaigns, params) req.send_request() end |
#list_decoder_manifest_network_interfaces(params = {}) ⇒ Types::ListDecoderManifestNetworkInterfacesResponse
Lists the network interfaces specified in a decoder manifest.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2462 2463 2464 2465 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2462 def list_decoder_manifest_network_interfaces(params = {}, = {}) req = build_request(:list_decoder_manifest_network_interfaces, params) req.send_request() end |
#list_decoder_manifest_signals(params = {}) ⇒ Types::ListDecoderManifestSignalsResponse
A list of information about signal decoders specified in a decoder manifest.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2548 2549 2550 2551 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2548 def list_decoder_manifest_signals(params = {}, = {}) req = build_request(:list_decoder_manifest_signals, params) req.send_request() end |
#list_decoder_manifests(params = {}) ⇒ Types::ListDecoderManifestsResponse
Lists decoder manifests.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2612 2613 2614 2615 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2612 def list_decoder_manifests(params = {}, = {}) req = build_request(:list_decoder_manifests, params) req.send_request() end |
#list_fleets(params = {}) ⇒ Types::ListFleetsResponse
Retrieves information for each created fleet in an Amazon Web Services account.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2670 2671 2672 2673 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2670 def list_fleets(params = {}, = {}) req = build_request(:list_fleets, params) req.send_request() end |
#list_fleets_for_vehicle(params = {}) ⇒ Types::ListFleetsForVehicleResponse
Retrieves a list of IDs for all fleets that the vehicle is associated with.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2721 2722 2723 2724 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2721 def list_fleets_for_vehicle(params = {}, = {}) req = build_request(:list_fleets_for_vehicle, params) req.send_request() end |
#list_model_manifest_nodes(params = {}) ⇒ Types::ListModelManifestNodesResponse
Lists information about nodes specified in a vehicle model (model manifest).
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2821 2822 2823 2824 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2821 def list_model_manifest_nodes(params = {}, = {}) req = build_request(:list_model_manifest_nodes, params) req.send_request() end |
#list_model_manifests(params = {}) ⇒ Types::ListModelManifestsResponse
Retrieves a list of vehicle models (model manifests).
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2884 2885 2886 2887 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2884 def list_model_manifests(params = {}, = {}) req = build_request(:list_model_manifests, params) req.send_request() end |
#list_signal_catalog_nodes(params = {}) ⇒ Types::ListSignalCatalogNodesResponse
Lists of information about the signals (nodes) specified in a signal catalog.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2988 2989 2990 2991 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 2988 def list_signal_catalog_nodes(params = {}, = {}) req = build_request(:list_signal_catalog_nodes, params) req.send_request() end |
#list_signal_catalogs(params = {}) ⇒ Types::ListSignalCatalogsResponse
Lists all the created signal catalogs in an Amazon Web Services account.
You can use to list information about each signal (node) specified in a signal catalog.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3041 3042 3043 3044 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3041 def list_signal_catalogs(params = {}, = {}) req = build_request(:list_signal_catalogs, params) req.send_request() end |
#list_state_templates(params = {}) ⇒ Types::ListStateTemplatesResponse
Lists information about created state templates.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see [Amazon Web Services Region and feature availability] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleetwise-regions.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3098 3099 3100 3101 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3098 def list_state_templates(params = {}, = {}) req = build_request(:list_state_templates, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags (metadata) you have assigned to the resource.
3126 3127 3128 3129 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3126 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_vehicles(params = {}) ⇒ Types::ListVehiclesResponse
Retrieves a list of summaries of created vehicles.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3221 3222 3223 3224 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3221 def list_vehicles(params = {}, = {}) req = build_request(:list_vehicles, params) req.send_request() end |
#list_vehicles_in_fleet(params = {}) ⇒ Types::ListVehiclesInFleetResponse
Retrieves a list of summaries of all vehicles associated with a fleet.
<note markdown=“1”> This API operation uses pagination. Specify the ‘nextToken` parameter in the request to return more results.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3271 3272 3273 3274 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3271 def list_vehicles_in_fleet(params = {}, = {}) req = build_request(:list_vehicles_in_fleet, params) req.send_request() end |
#put_encryption_configuration(params = {}) ⇒ Types::PutEncryptionConfigurationResponse
Creates or updates the encryption configuration. Amazon Web Services IoT FleetWise can encrypt your data and resources using an Amazon Web Services managed key. Or, you can use a KMS key that you own and manage. For more information, see [Data encryption] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/data-encryption.html
3315 3316 3317 3318 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3315 def put_encryption_configuration(params = {}, = {}) req = build_request(:put_encryption_configuration, params) req.send_request() end |
#put_logging_options(params = {}) ⇒ Struct
Creates or updates the logging option.
3338 3339 3340 3341 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3338 def (params = {}, = {}) req = build_request(:put_logging_options, params) req.send_request() end |
#register_account(params = {}) ⇒ Types::RegisterAccountResponse
This API operation contains deprecated parameters. Register your account again without the Timestream resources parameter so that Amazon Web Services IoT FleetWise can remove the Timestream metadata stored. You should then pass the data destination into the
- CreateCampaign][1
-
API operation.
You must delete any existing campaigns that include an empty data
destination before you register your account again. For more information, see the [DeleteCampaign] API operation.
If you want to delete the Timestream inline policy from the
service-linked role, such as to mitigate an overly permissive policy, you must first delete any existing campaigns. Then delete the service-linked role and register your account again to enable CloudWatch metrics. For more information, see
- DeleteServiceLinkedRole][3
-
in the *Identity and Access Management
API Reference*.
Registers your Amazon Web Services account, IAM, and Amazon Timestream resources so Amazon Web Services IoT FleetWise can transfer your vehicle data to the Amazon Web Services Cloud. For more information, including step-by-step procedures, see [Setting up Amazon Web Services IoT FleetWise].
<note markdown=“1”> An Amazon Web Services account is not the same thing as a “user.” An [Amazon Web Services user] is an identity that you create using Identity and Access Management (IAM) and takes the form of either an [IAM user] or an [IAM role, both with credentials]. A single Amazon Web Services account can, and typically does, contain many users and roles.
</note>
[1]: docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_CreateCampaign.html [2]: docs.aws.amazon.com/iot-fleetwise/latest/APIReference/API_DeleteCampaign.html [3]: docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServiceLinkedRole.html [4]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/setting-up.html [5]: docs.aws.amazon.com/IAM/latest/UserGuide/introduction_identity-management.html#intro-identity-users [6]: docs.aws.amazon.com/IAM/latest/UserGuide/id_users.html [7]: docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html
3425 3426 3427 3428 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3425 def register_account(params = {}, = {}) req = build_request(:register_account, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource.
3455 3456 3457 3458 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3455 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the given tags (metadata) from the resource.
3479 3480 3481 3482 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3479 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_campaign(params = {}) ⇒ Types::UpdateCampaignResponse
Updates a campaign.
3537 3538 3539 3540 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3537 def update_campaign(params = {}, = {}) req = build_request(:update_campaign, params) req.send_request() end |
#update_decoder_manifest(params = {}) ⇒ Types::UpdateDecoderManifestResponse
Updates a decoder manifest.
A decoder manifest can only be updated when the status is ‘DRAFT`. Only `ACTIVE` decoder manifests can be associated with vehicles.
3796 3797 3798 3799 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3796 def update_decoder_manifest(params = {}, = {}) req = build_request(:update_decoder_manifest, params) req.send_request() end |
#update_fleet(params = {}) ⇒ Types::UpdateFleetResponse
Updates the description of an existing fleet.
3828 3829 3830 3831 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3828 def update_fleet(params = {}, = {}) req = build_request(:update_fleet, params) req.send_request() end |
#update_model_manifest(params = {}) ⇒ Types::UpdateModelManifestResponse
Updates a vehicle model (model manifest). If created vehicles are associated with a vehicle model, it can’t be updated.
3877 3878 3879 3880 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 3877 def update_model_manifest(params = {}, = {}) req = build_request(:update_model_manifest, params) req.send_request() end |
#update_signal_catalog(params = {}) ⇒ Types::UpdateSignalCatalogResponse
Updates a signal catalog.
4046 4047 4048 4049 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4046 def update_signal_catalog(params = {}, = {}) req = build_request(:update_signal_catalog, params) req.send_request() end |
#update_state_template(params = {}) ⇒ Types::UpdateStateTemplateResponse
Updates a state template.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see [Amazon Web Services Region and feature availability] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleetwise-regions.html
4128 4129 4130 4131 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4128 def update_state_template(params = {}, = {}) req = build_request(:update_state_template, params) req.send_request() end |
#update_vehicle(params = {}) ⇒ Types::UpdateVehicleResponse
Updates a vehicle.
Access to certain Amazon Web Services IoT FleetWise features is currently gated. For more information, see [Amazon Web Services Region and feature availability] in the *Amazon Web Services IoT FleetWise Developer Guide*.
[1]: docs.aws.amazon.com/iot-fleetwise/latest/developerguide/fleetwise-regions.html
4232 4233 4234 4235 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4232 def update_vehicle(params = {}, = {}) req = build_request(:update_vehicle, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4261 4262 4263 |
# File 'lib/aws-sdk-iotfleetwise/client.rb', line 4261 def waiter_names [] end |